@@ -39,8 +39,40 @@ struct var_struct
   NumericMatrix OutputMatrixB;
   int IterationCounter;
   bool FinishIteratation;
+  var_struct();
 };
 
+
+var_struct::var_struct()
+{
+  CurrentPiece = 0;
+  RangePiece = 0;
+  y = 0.0;
+  MinimizerA = 0.0;
+  MinimizerB = 0.0;
+  MinimizerC = 0.0;
+  MinimizerWhich = 0;
+  MinimizerPiece = 0;
+  KnotTracker = 0;
+  Scratch = FALSE;
+  NewMinimizerKnown = FALSE;
+  WasLastIntersect = FALSE;
+  LastIntersectUpperRootTrue = FALSE;
+  LastIntersectWhich = 0;
+  LastIntersectPiece = 0;
+  ActiveA = 0;
+  IntersectHowMany = 0;
+  IntersectCounter = 0;
+  ActiveIntersectA = FALSE;
+  ActiveIntersectC = FALSE; 
+  OutputCounter = 0;
+  IterationCounter = 0;
+  FinishIteratation = FALSE;
+}
+
+
+
+
 struct ab_struct
 {
   NumericVector TypeAKnot, TypeAValue, TypeBLeftKnot, TypeBRightKnot, TypeBCoefA, TypeBCoefB, TypeBCoefC;
@@ -49,6 +81,8 @@ struct ab_struct
 
 
 
+
+
 void DoIteration( const double& NextWeight, const double& NextResponse, const int& IterationCounter, const double& gamma, const double& lambda,
                   NumericVector& CoefA, NumericVector& CoefB, NumericVector& CoefC, NumericVector& LeftKnot, NumericVector& RightKnot,
                   NumericMatrix& InputMatrixB );
